Clazz.declarePackage("JU");
Clazz.load(["java.lang.RuntimeException"], "JU.JSONException", null, function(){
var c$ = Clazz.declareType(JU, "JSONException", RuntimeException);
});
;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
